@@ -1,5 +1,5 @@
 package POEx::ZMQ3;
-our $VERSION = '0.05';
+$POEx::ZMQ3::VERSION = '0.07';
 use strictures 1;
 use Carp;
 
@@ -19,6 +19,11 @@ sub import {
   1
 }
 
+=pod
+
+=for Pod::Coverage new
+
+=cut
 
 sub new {
   my $class = shift;
@@ -33,30 +38,36 @@ sub new {
 
 =head1 NAME
 
-POEx::ZMQ3 - POE-enabled asynchronous ZeroMQ components
+POEx::ZMQ3 - **DEPRECATED** See POEx::ZMQ instead
 
 =head1 SYNOPSIS
 
   use POEx::ZMQ3;
-  ## A POEx::ZMQ3::Sockets instance:
+  # A POEx::ZMQ3::Sockets instance:
   my $zmq = POEx::ZMQ3->new;
-
-(See L<POEx::ZMQ3::Sockets> for a complete example.)
+  # See POEx::ZMQ3::Sockets for a complete example.
 
 =head1 DESCRIPTION
 
+B<< This distribution is deprecated and known broken with ZMQ4+! >>
+It will likely be deleted in the future.
+
+B<< See L<POEx::ZMQ> instead >>. As of this writing, developer releases are
+available on CPAN, and you can help by contributing issues and/or fixes for
+same at L<http://www.github.com/avenj/poex-zmq>.
+
 A set of roles and classes providing a L<POE>-enabled asynchronous interface
 to B<ZeroMQ> (version 3) via L<ZMQ::LibZMQ3>.
 
 ZeroMQ is a powerful high-performance messaging library aimed at
-concurrent/distributed applications. (If you're just getting started with
-ZeroMQ, it is strongly advised you read the 'zguide'
-(L<http://zguide.zeromq.org>) before jumping in.)
+concurrent/distributed applications. If you're just getting started with
+ZeroMQ, it is strongly advised you read the B<zguide>
+(L<http://zguide.zeromq.org>) before jumping in.
 
-This project attempts to stay on top of changes in ZeroMQ and the relevant
-Perl bindings. 
 You will need B<zeromq-3.2.2> or newer: L<http://www.zeromq.org>
 
+This is early development software; see L</BUGS>.
+
 =head2 Classes
 
 L<POEx::ZMQ3::Sockets> is the backend ZMQ component. It can be used directly
@@ -81,9 +92,17 @@ but these can be easily implemented with L<POEx::ZMQ3::Sockets>.
 L<MooX::Role::POE::Emitter> provides L<POE> event emitter functionality and
 some endpoint management methods.
 
+=head1 CAVEATS
+
+=head2 Forking
+
+If your application forks, the global context object needs to be reset by 
+calling C<< POEx::ZMQ3::Context->reset >> before creating sockets. 
+See L<POEx::ZMQ3::Context>.
+
 =head1 BUGS
 
-Probably many; this software is fairly early in development.
+Probably many undiscovered; this software is fairly early in development.
 
 See L<http://github.com/avenj/poex-zmq3> and feel free to report bugs via
 either B<RT> or B<GitHub>.
